default_panic_handler

Function default_panic_handler 

pub fn default_panic_handler(info: &PanicInfo<'_>) -> !
Provides a default panic handler that logs the panic to the cFE System Log and exits the application. This is highly recommended for all applications.

To use this, add the following to your application’s main.rs or lib.rs:

#[panic_handler]
fn panic(info: &core::panic::PanicInfo) -> ! { // This signature is required.
    libcfs::es::app::default_panic_handler(info);
}