AppInfo

Struct AppInfo 

pub struct AppInfo { /* private fields */ }
A high-level wrapper around the FFI’s CFE_ES_AppInfo_t.

This struct contains detailed information about a cFE application, such as its name, entry point, memory layout, and task IDs.

Implementations

Source

impl AppInfo

pub fn name(&self) -> Result<CString<{ _ }>>

Returns the registered name of the application.

Errors

Returns an error if the name from the underlying FFI struct is not valid UTF-8 or cannot fit into the CString buffer.

pub fn copy_entry_point<'a>(&self, buffer: &'a mut [u8]) -> Result<&'a str>

Copies the entry point name of the application into the provided buffer. Returns a &str slice of the valid UTF-8 part of the buffer.

Arguments
  • buffer: A mutable byte slice to copy the name into.
Errors

Returns an error if the buffer is too small or the name is not valid UTF-8.

pub fn copy_file_name<'a>(&self, buffer: &'a mut [u8]) -> Result<&'a str>

Copies the file name of the application into the provided buffer. Returns a &str slice of the valid UTF-8 part of the buffer.

Arguments
  • buffer: A mutable byte slice to copy the name into.
Errors

Returns an error if the buffer is too small or the name is not valid UTF-8.