CdsInfo

Enum CdsInfo 

pub enum CdsInfo {
    Created,
    Restored,
}
Information about the status of a CDS block upon registration.

Variants



Created

The CDS block was newly created and its contents are uninitialized.



Restored

The CDS block already existed and its contents have been restored.