pub struct PerfMarker { /* private fields */ }Expand description
A performance marker that logs entry and exit points for performance measurement.
Automatically starts logging on creation and stops logging when dropped.
Implementations