pub struct BlockStats {
pub block_size: u32,
pub num_created: u32,
pub num_free: u32,
}Expand description
Statistics about a specific block size within a memory pool.
Fields
block_size: u32Number of bytes in each of these blocks.
num_created: u32Number of memory blocks of this size created.
num_free: u32Number of memory blocks of this size that are free.