pub struct MemPoolStats {
pub pool_size: u32,
pub num_blocks_requested: u32,
pub check_err_ctr: u32,
pub num_free_bytes: u32,
pub block_stats: [BlockStats; 17],
}Expand description
Statistics about a cFE memory pool.
Fields
pool_size: u32Total size of the memory pool in bytes.
num_blocks_requested: u32Number of times a memory block has been allocated.
check_err_ctr: u32Number of errors detected when freeing a memory block.
num_free_bytes: u32Number of bytes never allocated to a block.
block_stats: [BlockStats; 17]Statistics for each available block size.