ResourceId

Struct ResourceId 

#[repr(transparent)]
pub struct ResourceId(pub u32);
A generic, type-safe wrapper for a CFE Resource ID.

Tuple Fields

0: u32

Implementations

Source

impl ResourceId

pub fn base(&self) -> u32

Gets the base value (type/category) from this resource ID.

pub fn serial(&self) -> u32

Gets the serial number from this resource ID.

pub fn module_info(&self) -> Result<AppInfo>

Retrieves information about an Application or Library given this Resource ID.

This is a generic wrapper that can be used for either an AppId or a LibId.