ResetType

Enum ResetType 

#[repr(u32)]
pub enum ResetType { Processor = 1, PowerOn = 2, Unknown(u32), }
The type of reset the processor most recently underwent.

Variants



Processor = 1

A processor reset, where volatile memory areas may have been preserved.



PowerOn = 2

A power-on reset, where all memory has been cleared.



Unknown(u32)

An unknown or unhandled reset type.