background_wakeup

Function background_wakeup 

pub fn background_wakeup()
Wakes up the ES background task to process pending jobs.

Normally the ES background task wakes up at a periodic interval. Whenever new background work is added, this can be used to wake the task early, which may reduce the delay before the job is processed.

Work is pro-rated based on elapsed time since the last wakeup. Waking the task early does not cause extra work to be done.