pub fn process_async_event()Expand description
Notifies ES that an asynchronous event was detected by the underlying OS/PSP.
This hook routine is called from the PSP when an exception or other asynchronous system event occurs.
Must not be invoked directly from ISR or signal context. The PSP must guarantee it runs from a context that can use OSAL primitives.