wait_for_startup_sync

Function wait_for_startup_sync 

pub fn wait_for_startup_sync(timeout: Duration)
Allows an application to wait until all cFE apps have reached the OPERATIONAL state.

This is a convenience wrapper for wait_for_system_state(SystemState::Operational, ...).

Timeout values below 1000 ms are rounded up to 1000 ms. Should only be called as the last step of application init, and only by apps started from the ES startup file.

Arguments

  • timeout: The maximum duration to wait.