increment_task_counter

Function increment_task_counter 

pub fn increment_task_counter()
Increments the execution counter for the calling task.

This is typically not needed for main application tasks that call run_cycle (via CFE_ES_RunLoop), as the counter is incremented automatically. It is useful for child tasks or other contexts where the counter needs to be manually managed to indicate liveness.