TaskId

Struct TaskId 

pub struct TaskId(pub u32);
A type-safe, zero-cost wrapper for a cFE Task ID.

Tuple Fields

0: u32

Implementations

Source

impl TaskId

pub fn info(&self) -> Result<TaskInfo>

Retrieves detailed information about the task with this ID.

pub fn delete(&self) -> Result<()>

Deletes a child task with this ID.

This function is a standalone wrapper for CFE_ES_DeleteChildTask. Using the ChildTask RAII struct is generally preferred to ensure the task is always deleted. It must not be called for an Application’s Main Task.

pub fn name(&self) -> Result<CString<{ _ }>>

Retrieves the cFE Task Name for this task ID.

pub fn to_index(&self) -> Result<u32>

Converts this CFE Task ID into a zero-based integer suitable for array indexing.

pub fn from_name(name: &str) -> Result<Self>

Retrieves the cFE Task ID for a given task name.

pub fn current() -> Result<Self>

Retrieves the CFE Task ID of the currently executing task.