TableInfo

Struct TableInfo 

pub struct TableInfo(/* private fields */);
Information about a cFE table.

Implementations

Source

impl TableInfo

pub fn size(&self) -> usize

Returns the size of the table in bytes.

pub fn num_users(&self) -> u32

Returns the number of applications with access to the table.

pub fn file_time(&self) -> SysTime

Returns the file creation time from the last file loaded into the table.

pub fn crc(&self) -> u32

Returns the most recently calculated CRC of the table contents.

pub fn time_of_last_update(&self) -> SysTime

Returns the time when the table was last updated.

pub fn table_loaded_once(&self) -> bool

Returns whether the table has been loaded at least once.

pub fn dump_only(&self) -> bool

Returns whether the table is marked as Dump Only.

pub fn double_buffered(&self) -> bool

Returns whether the table is double-buffered.

pub fn user_def_addr(&self) -> bool

Returns whether the table address was defined by the owner application.

pub fn critical(&self) -> bool

Returns whether the table is critical (backed by the CDS).

pub fn last_file_loaded(&self) -> &str

Returns the filename of the last file loaded into the table.