CfsError

Enum CfsError 

#[non_exhaustive]
pub enum CfsError {
Show 22 variants Evs(EvsError), Es(EsError), Sb(SbError), Fs(FsError), Tbl(TblError), Time(TimeError), Osal(OsalError), WrongMsgLength, UnknownMsgId, BadCommandCode, ExternalResourceFail, RequestAlreadyPending, ValidationFailure, RangeError, IncorrectState, NotImplemented, InvalidString, TaskPoolFull, TaskTooLarge, TaskAlignmentTooLarge, ConversionError(&'static str), Unhandled(i32),
}
Represents all possible errors and status codes from the CFE and OSAL APIs.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Evs(EvsError)

An EVS (Event Services) error.



Es(EsError)

An ES (Executive Services) error.



Sb(SbError)

An SB (Software Bus) error.



Fs(FsError)

An FS (File Services) error.



Tbl(TblError)

A TBL (Table Services) error.



Time(TimeError)

A TIME (Time Services) error.



Osal(OsalError)

An OSAL error.



WrongMsgLength

The message length is incorrect.



UnknownMsgId

The message ID is unknown.



BadCommandCode

The command code is invalid.



ExternalResourceFail

An external resource failure occurred.



RequestAlreadyPending

The request is already pending.



ValidationFailure

Validation of the input failed.



RangeError

The input value is out of the valid range.



IncorrectState

The request cannot be processed in the current state.



NotImplemented

The requested function is not implemented.



InvalidString

The string contains an interior null character.



TaskPoolFull

The task pool is full and cannot accept new tasks.



TaskTooLarge

The task’s stack size exceeds the maximum allowed.



TaskAlignmentTooLarge

The task’s alignment exceeds the maximum allowed.



ConversionError(&'static str)

A type conversion error occurred.



Unhandled(i32)

An unhandled error code was returned by the C API.

Implementations

Source

impl CfsError

pub fn name(error: i32) -> Result<CString<{ _ }>>

Retrieves the symbolic name for an OSAL status code.