printf

Function printf 

pub fn printf(message: &str)
Writes a message string to the OSAL console (OS_printf).

This is a low-level wrapper around the C OS_printf function. The printf! macro is generally more convenient to use. This function does not return an error and is considered a “best-effort” logging mechanism.

Arguments

  • message: The string to write. It will be truncated if its byte length exceeds MAX_PRINTF_MSG_SIZE.