add_fixed_map

Function add_fixed_map 

pub fn add_fixed_map(phys_path: &str, virt_path: &str) -> Result<OsalId>
Creates a fixed mapping between a physical host path and a virtual OSAL mount point.

This is typically called by the PSP/BSP before application startup to configure the virtual filesystem.