extract_filename_from_path

Function extract_filename_from_path 

pub fn extract_filename_from_path<'a>(
    original_path: &str,
    filename_buf: &'a mut [u8; 64],
) -> Result<&'a str>
Extracts the filename from a unix style path and filename string.

Returns a &str slice of the valid filename within the provided buffer.