pub fn get_default_mount_point(category: FileCategory) -> Option<&'static str>Expand description
Gets the default virtual mount point for a file category (e.g., “/ram” or “/cf”).
pub fn get_default_mount_point(category: FileCategory) -> Option<&'static str>Gets the default virtual mount point for a file category (e.g., “/ram” or “/cf”).