init_fs

Function init_fs 

pub fn init_fs(
    address: *mut u8,
    devname: &str,
    volname: &str,
    blocksize: usize,
    numblocks: usize,
) -> Result<()>
Initializes an existing file system on the target.

This is a low-level function for preparing a block device or memory region for use, but without creating it from scratch like make_fs.