pub struct FileWriteMetaData(/* private fields */);Expand description
Metadata and state for a background file write operation.
This struct should be stored in a persistent memory location (e.g., a static)
for the duration of the asynchronous file write.