FsHeader

Struct FsHeader 

pub struct FsHeader(/* private fields */);
A safe, idiomatic wrapper for a cFE file header.

Implementations

Source

impl FsHeader

pub fn new(description: &str, subtype: u32) -> Result<Self>

Creates and initializes a new cFE file header with the specified description and subtype.

The description will be truncated if it is longer than the header field allows.