HeapInfo

Struct HeapInfo 

pub struct HeapInfo {
    pub free_bytes: usize,
    pub free_blocks: usize,
    pub largest_free_block: usize,
}
A snapshot of statistics for the system’s dynamic memory heap.

Fields

free_bytes: usize

Total number of free bytes available in the heap.

free_blocks: usize

Total number of free blocks in the heap.

largest_free_block: usize

The size of the largest contiguous free block available.

Implementations

Source

impl HeapInfo

pub fn query() -> Result<HeapInfo>

Retrieves statistics about the current state of the system heap.

This function is a safe wrapper around OS_HeapGetInfo.