for_each_object

Function for_each_object 

pub fn for_each_object<F>(creator_id: Option<OsalId>, callback: F)
where F: FnMut(OsalId),
Iterates over all OSAL objects and calls a closure for each one.

Arguments

  • creator_id: If Some(id), only objects created by that task ID are processed. If None, all objects are processed.
  • callback: A closure that will be called with the ID of each object.