symbol_lookup

Function symbol_lookup 

pub fn symbol_lookup(name: &str) -> Result<*mut c_void>
Looks up the address of a symbol in the global symbol table.

This can find symbols in the main executable or in any module loaded with ModuleFlags::GLOBAL_SYMBOLS.

Safety

Using the returned pointer is inherently unsafe. The caller must ensure it is cast to the correct function pointer type and that the function signature is correct. The lifetime of the symbol is not managed by this function.