TcpStream

Struct TcpStream 

pub struct TcpStream(/* private fields */);
A TCP stream between a local and a remote socket.

Implementations

Source

impl TcpStream

pub fn connect(addr: SocketAddr, domain: SocketDomain) -> Result<Self>

Opens a TCP connection to a remote host.

pub fn read(&mut self, buf: &mut [u8]) -> Result<usize>

Reads some bytes from the stream into the specified buffer.

pub fn write(&mut self, buf: &[u8]) -> Result<usize>

Writes a buffer to the stream.

pub fn accept_abs(&self, abstime: OsTime) -> Result<(TcpStream, SocketAddr)>

Accepts a new connection with an absolute timeout.

pub fn connect_abs( addr: SocketAddr, domain: SocketDomain, abstime: OsTime, ) -> Result<Self>

Opens a TCP connection to a remote host with an absolute timeout.

pub fn shutdown(&self, how: SocketShutdownMode) -> Result<()>

Gracefully shuts down the read, write, or both halves of the connection.