UdpSocket

Struct UdpSocket 

pub struct UdpSocket(/* private fields */);
A UDP socket.

Implementations

Source

impl UdpSocket

pub fn id(&self) -> OsalId

Returns the OSAL id for this socket, suitable for passing to OS_SelectMultiple via the runtime reactor.

pub fn bind(addr: SocketAddr) -> Result<UdpSocket>

Creates a new UDP socket bound to the specified address.

pub fn recv_from<'a>( &self, buf: &'a mut [u8], timeout: Timeout, ) -> Result<(usize, SocketAddr)>

Receives a single datagram message on the socket.

pub fn send_to(&self, buf: &[u8], target: &SocketAddr) -> Result<usize>

Sends data on the socket to the given address.

pub fn recv_from_abs<'a>( &self, buf: &'a mut [u8], abstime: OsTime, ) -> Result<(usize, SocketAddr)>

Receives a datagram with an absolute timeout.

Source

impl UdpSocket

pub fn recv<'a>( &'a self, buf: &'a mut [u8], ) -> impl Future<Output = Result<(usize, SocketAddr)>> + use<'a>

Asynchronously receives a single datagram message on the socket.

pub fn send<'a>( &'a self, buf: &'a [u8], target: &'a SocketAddr, ) -> impl Future<Output = Result<usize>> + use<'a>

Asynchronously sends data on the socket to the given address.