Mutex

Struct Mutex 

pub struct Mutex { /* private fields */ }
A mutual exclusion primitive useful for protecting shared data.

This mutex will block tasks waiting for the lock to become available.

Implementations

Source

impl Mutex

pub fn new(name: &str) -> Result<Self>

Creates a new OSAL mutex in the unlocked (available) state.

Arguments
  • name: A unique string to identify the mutex.
pub fn lock(&self) -> Result<MutexGuard<'_>>

Acquires a mutex, blocking the current task until it is able to do so.

This function returns a MutexGuard when the lock has been acquired. The guard ensures that the lock is automatically released when it goes out of scope.

pub fn get_id_by_name(name: &str) -> Result<OsalId>

Finds an existing mutex ID by its name.

pub fn get_info(&self) -> Result<MutexProp>

Retrieves information about this mutex.