find_id_by_system_data

Function find_id_by_system_data 

pub unsafe fn find_id_by_system_data(
    sys_data: *const (),
    sys_data_size: usize,
) -> Result<TaskId>
Reverse-looks up an OSAL task ID from an underlying operating system ID.

This is for special cases like exception handling where the OS provides a native task ID that needs to be mapped back to an OSAL ID.

Safety

The sys_data pointer must be a valid pointer to the OS-specific task identifier data, and sys_data_size must be the correct size of that data.