Task

Struct Task 

pub struct Task { /* private fields */ }
A handle to an OSAL task.

This is a wrapper around an osal_id_t that will automatically call OS_TaskDelete when it goes out of scope, preventing resource leaks.

Implementations

Source

impl Task

pub fn new( name: &str, entry_point: unsafe extern "C" fn(), stack_size: usize, priority: u8, flags: TaskFlags, ) -> Result<Self>

Creates a new OSAL task and starts it running.

The stack for the task is allocated from the system memory heap.

Arguments
  • name: A unique string to identify the task.
  • entry_point: The function that the new task will execute. This must be a free function with extern "C" linkage.
  • stack_size: The size of the stack to allocate for the new task. A value of 0 is non-portable: some RTOS use a default, others create a task with no stack. Always specify an actual size.
  • priority: The priority of the new task (0=highest, 255=lowest).
  • flags: Task creation flags (e.g. TaskFlags::FP_ENABLED).
pub fn id(&self) -> TaskId

Returns the underlying TaskId for this task.

pub fn get_info(&self) -> Result<TaskProp>

Retrieves information about this task.