TimeBase

Struct TimeBase 

pub struct TimeBase { /* private fields */ }
A handle to an OSAL time base.

A time base is an abstraction of a “timer tick” that can be used for measuring elapsed time or scheduling timer callbacks. This wrapper manages a software-simulated time base provided by the OSAL.

Implementations

Source

impl TimeBase

pub fn new(name: &str) -> Result<Self>

Creates a new software-simulated OSAL time base.

This time base will use the underlying OS kernel’s timing facilities. The timer does not start until set() is called.

This creates a servicing task at elevated priority that may interrupt user tasks. The kernel must be configured for OS_MAX_TASKS + OS_MAX_TIMEBASES threads.

Must not be called from the context of a timer callback.

Arguments
  • name: A unique string to identify the time base.
pub fn set(&self, start: Duration, interval: Duration) -> Result<()>

Programs the time base for a one-shot or periodic tick.

Must not be called from the context of a timer callback.

Arguments
  • start: Duration until the first tick.
  • interval: Duration between subsequent ticks. If Duration::ZERO, the time base will only tick once.
pub fn id(&self) -> TimeBaseId

Returns the underlying TimeBaseId.

pub fn info(&self) -> Result<TimeBaseProp>

Retrieves information about this time base.