copy_context

Function copy_context 

pub unsafe fn copy_context(
    context_log_id: u32,
    context_buf: &mut [u8],
) -> Result<usize>
Copies the processor context of a specific exception log entry into a buffer.

Returns the number of bytes copied. May return NO_EXCEPTION_DATA if the context data has expired from the circular memory log.

Safety

The context_buf must be a valid, writable buffer of at least context_buf.len() bytes.