flush_caches

Function flush_caches 

pub unsafe fn flush_caches(cache_type: u32, address: *mut (), size: u32)
Flushes processor data or instruction caches for a given memory range.

Safety

Flushing caches can have significant system-wide effects. The address and size must correspond to a valid memory region.