register_read

Function register_read 

pub fn register_read(waker: &Waker, id: OsalId)
Registers a read interest for id using the reactor carried in waker. No-op if the waker was not produced by a reactor-backed runtime.