sleep

Function sleep 

pub fn sleep(duration: Duration) -> Sleep 
Waits for a specified amount of time to pass.

This function is an async version of std::thread::sleep. It creates a future that will complete after the given duration has elapsed, without blocking the cFS task.