pub enum Status {
Show 17 variants
Success,
StatusNoCounterIncrement,
EsCdsAlreadyExists,
EsLibAlreadyLoaded,
EsErrSysLogTruncated,
TblInfoUpdatePending,
TblWarnDuplicate,
TblInfoUpdated,
TblWarnShortFile,
TblInfoNoUpdatePending,
TblInfoTableLocked,
TblInfoValidationPending,
TblInfoNoValidationPending,
TblWarnPartialLoad,
TblInfoDumpPending,
TblWarnNotCritical,
TblInfoRecoveredTbl,
}Expand description
Represents non-error, informational status codes from cFE APIs.
Variants
Success
Command was processed successfully.
StatusNoCounterIncrement
Command was processed successfully, but command counter should not be incremented.
EsCdsAlreadyExists
The application is receiving a pointer to a CDS that was already present.
EsLibAlreadyLoaded
CFE_ES_LoadLibrary detected that the requested library name is already loaded.
EsErrSysLogTruncated
The last syslog message was truncated.
TblInfoUpdatePending
The table has a load pending.
TblWarnDuplicate
A registration is trying to replace an existing table with the same name.
TblInfoUpdated
The table has been updated since the last time the address was obtained.
TblWarnShortFile
A table file contained less data than the size of the table.
TblInfoNoUpdatePending
An attempt was made to update a table without a pending load.
TblInfoTableLocked
An attempt was made to update a table locked by another user.
TblInfoValidationPending
The application should call CFE_TBL_Validate for the specified table.
TblInfoNoValidationPending
An attempt was made to validate a table that did not have a validation request pending.
TblWarnPartialLoad
A table file load did not start with the first byte.
TblInfoDumpPending
A dump of the Dump-Only table has been requested.
TblWarnNotCritical
A table registered as “Critical” failed to create a CDS.
TblInfoRecoveredTbl
A critical table’s contents were recovered from the CDS.