pub struct AppInfo { /* private fields */ }Expand description
A high-level wrapper around the FFI’s CFE_ES_AppInfo_t.
This struct contains detailed information about a cFE application, such as its name, entry point, memory layout, and task IDs.
Implementations
Sourceimpl AppInfo
impl AppInfo
Sourcepub fn name(&self) -> Result<CString<{ _ }>>
pub fn name(&self) -> Result<CString<{ _ }>>
Returns the registered name of the application.
Errors
Returns an error if the name from the underlying FFI struct is not
valid UTF-8 or cannot fit into the CString buffer.
Sourcepub fn copy_entry_point<'a>(&self, buffer: &'a mut [u8]) -> Result<&'a str>
pub fn copy_entry_point<'a>(&self, buffer: &'a mut [u8]) -> Result<&'a str>
Sourcepub fn copy_file_name<'a>(&self, buffer: &'a mut [u8]) -> Result<&'a str>
pub fn copy_file_name<'a>(&self, buffer: &'a mut [u8]) -> Result<&'a str>