#[repr(transparent)]pub struct LibId(pub u32);Expand description
A type-safe, zero-cost wrapper for a cFE Library ID.
This is a lightweight, Copy-able handle that represents a unique loaded library.
It can be used to query information about that specific library.
Tuple Fields
0: u32Implementations
Sourceimpl LibId
impl LibId
Sourcepub fn name(&self) -> Result<String<{ _ }>>
pub fn name(&self) -> Result<String<{ _ }>>
Retrieves the name for this library ID.
Errors
Returns an error if the Lib ID is not valid, the buffer is too small
(unlikely with heapless), or the name is not valid UTF-8.
Sourcepub fn info(&self) -> Result<AppInfo>
pub fn info(&self) -> Result<AppInfo>
Retrieves detailed information about the library with this ID.
Note: This reuses the AppInfo struct, as the underlying FFI type is the same.
Fields related to tasks (e.g., MainTaskId) will not be meaningful for a library.
Errors
Returns an error if the Lib ID is not valid or if the underlying CFE call fails.