pub struct TaskId(pub u32);Expand description
A type-safe, zero-cost wrapper for a cFE Task ID.
Tuple Fields
0: u32Implementations
Sourceimpl TaskId
impl TaskId
Sourcepub fn info(&self) -> Result<TaskInfo>
pub fn info(&self) -> Result<TaskInfo>
Retrieves detailed information about the task with this ID.
Sourcepub fn delete(&self) -> Result<()>
pub fn delete(&self) -> Result<()>
Deletes a child task with this ID.
This function is a standalone wrapper for CFE_ES_DeleteChildTask. Using the
ChildTask RAII struct is generally preferred to ensure the task is always deleted.
It must not be called for an Application’s Main Task.