pub fn calculate_crc(data: &[u8], input_crc: u32, crc_type: CrcType) -> u32Expand description
Calculates a cyclic redundancy check (CRC) on a block of memory.
This routine can be used to calculate a CRC on contiguous or non-contiguous blocks of memory.
Arguments
data: A slice of bytes to calculate the CRC over.input_crc: A starting value for the CRC calculation. For non-contiguous blocks, this should be the result of a previous call to this function. For a new calculation, this should typically be 0.crc_type: The CRC algorithm to use.