pub struct TableAccessor<'a, T: 'a> { /* private fields */ }Expand description
A safe RAII wrapper for accessing a CFE table’s memory.
It acquires the table pointer on creation and automatically releases it when dropped.
Implementations
Sourceimpl<'a, T> TableAccessor<'a, T>
impl<'a, T> TableAccessor<'a, T>
Sourcepub fn new(handle: TableHandle) -> Result<Self>
pub fn new(handle: TableHandle) -> Result<Self>
Acquires a pointer to the table data.
Can block on shared single-buffered tables. The address must
be released (by dropping the accessor) before calling
Table::update or any blocking call (e.g. pending on SB).
Returns a zeroed table pointer if the table has never been loaded.