pub struct TableInfo(/* private fields */);Expand description
Information about a cFE table.
Implementations
Sourceimpl TableInfo
impl TableInfo
Sourcepub fn file_time(&self) -> SysTime
pub fn file_time(&self) -> SysTime
Returns the file creation time from the last file loaded into the table.
Sourcepub fn time_of_last_update(&self) -> SysTime
pub fn time_of_last_update(&self) -> SysTime
Returns the time when the table was last updated.
Sourcepub fn table_loaded_once(&self) -> bool
pub fn table_loaded_once(&self) -> bool
Returns whether the table has been loaded at least once.
Sourcepub fn double_buffered(&self) -> bool
pub fn double_buffered(&self) -> bool
Returns whether the table is double-buffered.
Sourcepub fn user_def_addr(&self) -> bool
pub fn user_def_addr(&self) -> bool
Returns whether the table address was defined by the owner application.
Sourcepub fn last_file_loaded(&self) -> &str
pub fn last_file_loaded(&self) -> &str
Returns the filename of the last file loaded into the table.