pub enum OsalError {
Show 40 variants
Error,
InvalidPointer,
AddressMisaligned,
Timeout,
InvalidIntNum,
SemFailure,
SemTimeout,
QueueEmpty,
QueueFull,
QueueTimeout,
QueueInvalidSize,
QueueIdError,
NameTooLong,
NoFreeIds,
NameTaken,
InvalidId,
NameNotFound,
SemNotFull,
InvalidPriority,
InvalidSemValue,
File,
NotImplemented,
TimerInvalidArgs,
TimerIdError,
TimerUnavailable,
TimerInternal,
ObjectInUse,
BadAddress,
IncorrectObjState,
IncorrectObjType,
StreamDisconnected,
OperationNotSupported,
InvalidSize,
OutputTooLarge,
InvalidArgument,
FsPathTooLong,
FsNameTooLong,
FsDriveNotCreated,
FsDeviceNotFree,
FsPathInvalid,
}Expand description
OSAL errors.
Variants
Error
A generic OSAL error occurred.
InvalidPointer
An invalid pointer was provided.
AddressMisaligned
The address is not properly aligned.
Timeout
The operation timed out.
InvalidIntNum
The interrupt number is invalid.
SemFailure
A semaphore operation failed.
SemTimeout
A semaphore operation timed out.
QueueEmpty
The queue is empty.
QueueFull
The queue is full.
QueueTimeout
A queue operation timed out.
QueueInvalidSize
The queue size is invalid.
QueueIdError
The queue ID is invalid.
NameTooLong
The name exceeds the maximum allowed length.
NoFreeIds
No free IDs are available.
NameTaken
The requested name is already taken.
InvalidId
The object ID is invalid.
NameNotFound
The name was not found.
SemNotFull
The semaphore is not full.
InvalidPriority
The priority value is invalid.
InvalidSemValue
The semaphore value is invalid.
File
A file operation error occurred.
NotImplemented
The requested function is not implemented.
TimerInvalidArgs
Invalid arguments were passed to a timer function.
TimerIdError
The timer ID is invalid.
The timer is unavailable.
TimerInternal
An internal timer error occurred.
ObjectInUse
The object is currently in use.
BadAddress
The address is invalid.
IncorrectObjState
The object is in an incorrect state for the requested operation.
IncorrectObjType
The object type is incorrect for the requested operation.
StreamDisconnected
The stream has been disconnected.
OperationNotSupported
The requested operation is not supported on the supplied objects.
InvalidSize
The size is invalid.
OutputTooLarge
The output size exceeds the limit.
InvalidArgument
The argument value is invalid.
FsPathTooLong
The filesystem path exceeds the maximum length.
FsNameTooLong
The filesystem name exceeds the maximum length.
FsDriveNotCreated
The filesystem drive was not created.
FsDeviceNotFree
The filesystem device is not free.
FsPathInvalid
The filesystem path is invalid.