pub fn check_fs(path: &str, repair: bool) -> Result<()>
Checks the health of a file system and optionally repairs it.
Note: This functionality may not be implemented on all underlying operating systems.