pub fn mv(src: &str, dest: &str) -> Result<()>Expand description
Moves a single file from src to dest.
This will first attempt a rename, and if that fails (e.g., across different filesystems), it will fall back to a copy-then-delete operation.
Behavior on an open file is undefined at the OSAL level. Ensure the file is closed first.