File

Struct File 

pub struct File { /* private fields */ }
A handle to an open file.

This is a wrapper around an osal_id_t that will automatically call OS_close when it goes out of scope, preventing resource leaks.

Implementations

Source

impl File

pub fn id(&self) -> OsalId

Returns the underlying OSAL file ID.

pub fn open(path: &str, access: AccessMode) -> Result<Self>

Opens a file with the specified access mode.

Arguments
  • path: The virtual path to the file (e.g., “/ram/my_file.txt”).
  • access: The access mode, e.g., ffi::OS_READ_ONLY, ffi::OS_WRITE_ONLY, or ffi::OS_READ_WRITE.
pub fn create(path: &str) -> Result<Self>

Creates a new file, or truncates an existing one, with read/write access.

Arguments
  • path: The virtual path to the file to create (e.g., “/ram/new_file.dat”).
pub fn sync_read(&mut self, buf: &mut [u8]) -> Result<usize>

Reads some bytes from the file into the specified buffer.

Returns the number of bytes read.

pub fn sync_write(&mut self, buf: &[u8]) -> Result<usize>

Writes a buffer to the file.

Returns the number of bytes written.

pub fn seek(&mut self, pos: SeekFrom) -> Result<u32>

Seeks to an offset, in bytes, in a stream.

Returns the new position from the start of the file.

pub fn read_header(&mut self) -> Result<FsHeader>

Reads the standard cFE File Header from the file.

pub fn write_header(&mut self, hdr: &mut FsHeader) -> Result<()>

Writes the standard cFE File Header to the file.

pub fn set_timestamp(&mut self, time: SysTime) -> Result<()>

Modifies the timestamp field in the cFE File Header.

pub fn info(&self) -> Result<FileProp>

Retrieves information about this open file.

pub fn timed_read(&mut self, buf: &mut [u8], timeout_ms: i32) -> Result<usize>

Reads from the file with a relative timeout.

pub fn timed_read_abs( &mut self, buf: &mut [u8], abstime: OsTime, ) -> Result<usize>

Reads from the file with an absolute timeout.

pub fn timed_write(&mut self, buf: &[u8], timeout_ms: i32) -> Result<usize>

Writes to the file with a relative timeout.

pub fn timed_write_abs(&mut self, buf: &[u8], abstime: OsTime) -> Result<usize>

Writes to the file with an absolute timeout.

Source

impl File

pub fn read<'a>( &'a mut self, buf: &'a mut [u8], ) -> impl Future<Output = Result<usize>> + 'a

Asynchronously reads from the file into the provided buffer.

pub fn write<'a>( &'a mut self, buf: &'a [u8], ) -> impl Future<Output = Result<usize>> + 'a

Asynchronously writes the provided buffer to the file.