pub struct HeapInfo {
pub free_bytes: usize,
pub free_blocks: usize,
pub largest_free_block: usize,
}Expand description
A snapshot of statistics for the system’s dynamic memory heap.
Fields
free_bytes: usizeTotal number of free bytes available in the heap.
free_blocks: usizeTotal number of free blocks in the heap.
largest_free_block: usizeThe size of the largest contiguous free block available.
Implementations