pub fn for_each_object<F>(creator_id: Option<OsalId>, callback: F)Expand description
Iterates over all OSAL objects and calls a closure for each one.
Arguments
creator_id: IfSome(id), only objects created by that task ID are processed. IfNone, all objects are processed.callback: A closure that will be called with the ID of each object.