pub fn symbol_table_dump(filename: &str, size_limit: usize) -> Result<()>Expand description
Dumps the system symbol table to the specified file.
Not all RTOS support this. Returns OS_ERR_NOT_IMPLEMENTED
if not available.
Arguments
filename: The path to the file to write the symbol table to.size_limit: Maximum number of bytes to write.