pub struct OsTime(/* private fields */);Expand description
A wrapper around OS_time_t representing a specific local time.
This time is based on the underlying OS epoch (e.g., UNIX epoch) and is
distinct from cFE’s mission time (libcfs::time::SysTime).
Implementations
Sourceimpl OsTime
impl OsTime
Sourcepub fn from_relative_millis(millis: i32) -> Self
pub fn from_relative_millis(millis: i32) -> Self
Creates an OsTime instance from a relative duration in milliseconds.
This is a safe wrapper for OS_TimeFromRelativeMilliseconds.
Sourcepub fn to_relative_millis(&self) -> i32
pub fn to_relative_millis(&self) -> i32
Calculates the relative duration in milliseconds until this absolute time.
This is a safe wrapper for OS_TimeToRelativeMilliseconds.
Returns OS_CHECK (0) if the time is in the past, or OS_PEND (-1) if
the time is too far in the future to be represented.