#[repr(transparent)]pub struct TimeBaseId(pub u32);Expand description
A type-safe, zero-cost wrapper for an OSAL Time Base ID.
Tuple Fields
0: u32Implementations
Sourceimpl TimeBaseId
impl TimeBaseId
Sourcepub fn get_free_run(&self) -> Result<u32>
pub fn get_free_run(&self) -> Result<u32>
Reads the value of the timebase free-running counter.
This is a lightweight way to poll a monotonically increasing timer. The absolute value is not relevant, but differences between successive calls can be used for high-resolution timing.