pub fn get_summary() -> Result<ExceptionSummary>Expand description
Retrieves and pops the next exception log entry (destructive read).
Success does not guarantee all output fields contain valid data — only that they have been initialized.
pub fn get_summary() -> Result<ExceptionSummary>Retrieves and pops the next exception log entry (destructive read).
Success does not guarantee all output fields contain valid data — only that they have been initialized.