pub struct Runtime { /* private fields */ }Expand description
An async runtime designed to integrate with the cFS application lifecycle.
The runtime drives a single Future to completion by polling it
every time the cFS scheduler wakes the application.
Implementations